@@ -12,3 +12,7 @@ def factorial(n: int) -> int:
 		total *= i
 	return total
 
+
+def sum(*args):	return sum(args)
+def max(*args):	return max(args)
+def min(*args):	return min(args)
